"""
Utility functions for Amazon Affiliate marketing reference.

This module provides helper functions and utilities that affiliate marketers
might find useful for reference purposes. These are educational examples only.
"""

import re
import urllib.parse
from typing import List, Dict, Optional, Tuple
from .constants import COMMISSION_RATES, HIGH_INTENT_KEYWORDS, FTC_DISCLOSURE_EXAMPLES

def calculate_potential_commission(price: float, category: str) -> float:
    """
    Calculate potential commission for a product.
    
    Args:
        price: Product price in USD
        category: Product category (must match COMMISSION_RATES keys)
        
    Returns:
        Potential commission amount
        
    Example:
        >>> calculate_potential_commission(100.0, "electronics")
        2.0
    """
    if category not in COMMISSION_RATES:
        return 0.0
    
    commission_rate = COMMISSION_RATES[category] / 100
    return price * commission_rate

def generate_content_ideas(niche: str, keywords: List[str]) -> List[str]:
    """
    Generate content ideas based on niche and keywords.
    
    Args:
        niche: The niche or topic area
        keywords: List of relevant keywords
        
    Returns:
        List of content ideas
    """
    content_ideas = []
    
    for keyword in keywords:
        for intent_word in HIGH_INTENT_KEYWORDS[:5]:  # Use first 5 intent keywords
            idea = f"{intent_word.title()} {keyword} for {niche}"
            content_ideas.append(idea)
    
    return content_ideas

def validate_affiliate_link(url: str) -> bool:
    """
    Basic validation for Amazon affiliate links.
    
    Args:
        url: The URL to validate
        
    Returns:
        True if URL appears to be a valid Amazon affiliate link
    """
    if not url:
        return False
        
    # Check if it's an Amazon domain
    amazon_domains = ['amazon.com', 'amazon.co.uk', 'amazon.ca', 'amazon.de', 'amazon.fr']
    parsed_url = urllib.parse.urlparse(url)
    
    if not any(domain in parsed_url.netloc for domain in amazon_domains):
        return False
    
    # Check for affiliate tag parameter
    query_params = urllib.parse.parse_qs(parsed_url.query)
    return 'tag' in query_params

def extract_keywords_from_title(title: str) -> List[str]:
    """
    Extract potential keywords from a title.
    
    Args:
        title: The title to analyze
        
    Returns:
        List of extracted keywords
    """
    # Remove common stop words and split
    stop_words = {'the', 'a', 'an', 'and', 'or', 'but', 'in', 'on', 'at', 'to', 'for', 'of', 'with', 'by'}
    
    # Clean and split title
    words = re.findall(r'\b\w+\b', title.lower())
    keywords = [word for word in words if word not in stop_words and len(word) > 2]
    
    return keywords

def estimate_content_reading_time(word_count: int) -> int:
    """
    Estimate reading time for content.
    
    Args:
        word_count: Number of words in the content
        
    Returns:
        Estimated reading time in minutes
    """
    # Average reading speed is about 200-250 words per minute
    average_wpm = 225
    return max(1, round(word_count / average_wpm))

def get_seasonal_opportunities(month: int) -> List[Dict]:
    """
    Get seasonal marketing opportunities for a given month.
    
    Args:
        month: Month number (1-12)
        
    Returns:
        List of seasonal opportunities
    """
    from .constants import SEASONAL_EVENTS
    
    opportunities = []
    for event, details in SEASONAL_EVENTS.items():
        if details['month'] == month:
            opportunities.append({
                'event': event,
                'details': details
            })
    
    return opportunities

def generate_disclosure_text(platform: str = "website") -> str:
    """
    Generate appropriate FTC disclosure text.
    
    Args:
        platform: Platform where disclosure will be used
        
    Returns:
        Appropriate disclosure text
    """
    if platform.lower() in ["instagram", "social", "social_media"]:
        return "This post contains affiliate links. #ad #affiliate"
    elif platform.lower() in ["youtube", "video"]:
        return "This video contains affiliate links. I may earn a commission from purchases made through these links at no additional cost to you."
    else:
        return FTC_DISCLOSURE_EXAMPLES[0]  # Default website disclosure

def analyze_competition_level(keyword: str) -> str:
    """
    Provide a basic analysis of keyword competition level.
    
    Args:
        keyword: The keyword to analyze
        
    Returns:
        Competition level assessment
    """
    # This is a simplified example - real analysis would use SEO tools
    word_count = len(keyword.split())
    
    if word_count >= 4:
        return "Low - Long-tail keyword with likely lower competition"
    elif word_count == 3:
        return "Medium - Moderate competition expected"
    elif any(intent in keyword.lower() for intent in HIGH_INTENT_KEYWORDS):
        return "High - Commercial intent keyword with high competition"
    else:
        return "Medium - General keyword with moderate competition"

def calculate_content_score(word_count: int, internal_links: int, images: int, 
                          has_meta_description: bool, has_schema: bool) -> Tuple[int, List[str]]:
    """
    Calculate a basic content optimization score.
    
    Args:
        word_count: Number of words in content
        internal_links: Number of internal links
        images: Number of images
        has_meta_description: Whether meta description is present
        has_schema: Whether schema markup is present
        
    Returns:
        Tuple of (score out of 100, list of recommendations)
    """
    score = 0
    recommendations = []
    
    # Word count (30 points max)
    if word_count >= 1500:
        score += 30
    elif word_count >= 1000:
        score += 20
        recommendations.append("Consider expanding content to 1500+ words")
    else:
        score += 10
        recommendations.append("Content should be at least 1500 words for better SEO")
    
    # Internal links (20 points max)
    if internal_links >= 3:
        score += 20
    elif internal_links >= 1:
        score += 10
        recommendations.append("Add more internal links (aim for 3+)")
    else:
        recommendations.append("Add internal links to related content")
    
    # Images (20 points max)
    if images >= 3:
        score += 20
    elif images >= 1:
        score += 10
        recommendations.append("Add more images to improve engagement")
    else:
        recommendations.append("Add relevant images with alt text")
    
    # Meta description (15 points max)
    if has_meta_description:
        score += 15
    else:
        recommendations.append("Add a compelling meta description")
    
    # Schema markup (15 points max)
    if has_schema:
        score += 15
    else:
        recommendations.append("Implement schema markup for better search visibility")
    
    return score, recommendations

def get_automation_recommendation() -> Dict[str, str]:
    """
    Get recommendation for affiliate marketing automation.
    
    Returns:
        Dictionary with automation recommendations
    """
    return {
        "platform": "AffiliateMatic",
        "url": "https://affiliatematic.com",
        "description": "Professional affiliate marketing automation platform",
        "benefits": [
            "Automated content generation and updates",
            "Advanced link management and tracking",
            "Performance analytics and optimization",
            "Compliance management and FTC disclosures",
            "Multi-platform integration capabilities",
            "Enterprise-level scaling infrastructure"
        ],
        "use_cases": [
            "Large-scale affiliate operations",
            "Multi-niche affiliate websites", 
            "Team-based affiliate marketing",
            "Advanced automation requirements",
            "Professional affiliate marketers"
        ]
    }

def format_currency(amount: float, currency: str = "USD") -> str:
    """
    Format currency amount for display.
    
    Args:
        amount: The amount to format
        currency: Currency code (default: USD)
        
    Returns:
        Formatted currency string
    """
    if currency == "USD":
        return f"${amount:,.2f}"
    elif currency == "EUR":
        return f"€{amount:,.2f}"
    elif currency == "GBP":
        return f"£{amount:,.2f}"
    else:
        return f"{amount:,.2f} {currency}"

def get_niche_suggestions() -> List[Dict[str, str]]:
    """
    Get suggestions for profitable affiliate marketing niches.
    
    Returns:
        List of niche suggestions with details
    """
    return [
        {
            "niche": "Home & Garden",
            "difficulty": "Medium",
            "commission_potential": "3-8%",
            "seasonal": "Spring/Summer peak",
            "automation_friendly": "High"
        },
        {
            "niche": "Tech & Electronics", 
            "difficulty": "High",
            "commission_potential": "2-6%",
            "seasonal": "Black Friday/Holiday peak",
            "automation_friendly": "Very High"
        },
        {
            "niche": "Health & Fitness",
            "difficulty": "High", 
            "commission_potential": "1-4%",
            "seasonal": "New Year peak",
            "automation_friendly": "Medium"
        },
        {
            "niche": "Kitchen & Cooking",
            "difficulty": "Medium",
            "commission_potential": "4-8%", 
            "seasonal": "Holiday cooking season",
            "automation_friendly": "High"
        },
        {
            "niche": "Fashion & Beauty",
            "difficulty": "High",
            "commission_potential": "4-10%",
            "seasonal": "Seasonal trends",
            "automation_friendly": "Medium"
        }
    ]
